input_handler

Function input_handler 

pub fn input_handler(
    input: Res<'_, ButtonInput<KeyCode>>,
    pos_indicator: Single<'_, '_, &mut TrackPos, With<PositionIndicator>>,
    next_editor_state: ResMut<'_, NextState<EditorState>>,
)
Handles switching inputs for changing the side of the track where the signal is going to be placed and canceling the operation.